==> secretsmanager-1.60.0-sources.jar: software/amazon/awscdk/services/secretsmanager/AttachedSecretOptions.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Options to add a secret attachment to a secret.
 * <p>
 * @deprecated use `secret.attach()` instead
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.432Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.AttachedSecretOptions")
@software.amazon.jsii.Jsii.Proxy(AttachedSecretOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface AttachedSecretOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The target to attach the secret to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget getTarget();

    /**
     * @return a {@link Builder} of {@link AttachedSecretOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AttachedSecretOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<AttachedSecretOptions> {
        private software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target;

        /**
         * Sets the value of {@link AttachedSecretOptions#getTarget}
         * @param target The target to attach the secret to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder target(software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target) {
            this.target = target;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AttachedSecretOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public AttachedSecretOptions build() {
            return new Jsii$Proxy(target);
        }
    }

    /**
     * An implementation for {@link AttachedSecretOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AttachedSecretOptions {
        private final software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.target = this.jsiiGet("target", software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.target = java.util.Objects.requireNonNull(target, "target is required");
        }

        @Override
        public software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget getTarget() {
            return this.target;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("target", om.valueToTree(this.getTarget()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.AttachedSecretOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AttachedSecretOptions.Jsii$Proxy that = (AttachedSecretOptions.Jsii$Proxy) o;

            return this.target.equals(that.target);
        }

        @Override
        public int hashCode() {
            int result = this.target.hashCode();
            return result;
        }
    }
}

==> secretsmanager-1.100.0-sources.jar: software/amazon/awscdk/services/secretsmanager/AttachedSecretOptions.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * (deprecated) Options to add a secret attachment to a secret.
 * <p>
 * @deprecated use `secret.attach()` instead
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:15.660Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.AttachedSecretOptions")
@software.amazon.jsii.Jsii.Proxy(AttachedSecretOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface AttachedSecretOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The target to attach the secret to.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget getTarget();

    /**
     * @return a {@link Builder} of {@link AttachedSecretOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AttachedSecretOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<AttachedSecretOptions> {
        private software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target;

        /**
         * Sets the value of {@link AttachedSecretOptions#getTarget}
         * @param target The target to attach the secret to. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder target(software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target) {
            this.target = target;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AttachedSecretOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public AttachedSecretOptions build() {
            return new Jsii$Proxy(target);
        }
    }

    /**
     * An implementation for {@link AttachedSecretOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AttachedSecretOptions {
        private final software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.target = software.amazon.jsii.Kernel.get(this, "target", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget target) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.target = java.util.Objects.requireNonNull(target, "target is required");
        }

        @Override
        public final software.amazon.awscdk.services.secretsmanager.ISecretAttachmentTarget getTarget() {
            return this.target;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("target", om.valueToTree(this.getTarget()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-secretsmanager.AttachedSecretOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AttachedSecretOptions.Jsii$Proxy that = (AttachedSecretOptions.Jsii$Proxy) o;

            return this.target.equals(that.target);
        }

        @Override
        public final int hashCode() {
            int result = this.target.hashCode();
            return result;
        }
    }
}
